.. shoobx.immutable documentation master file, created by
   sphinx-quickstart on Thu May 30 15:32:38 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to :mod:`shoobx.immutable`'s documentation!
===================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   api
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
